import express from 'express';
import courseController from './course.controller';
import { sanitize } from '../../../middleware/sanitizer';
import { jwtStrategy } from '../../../middleware/strategy';
import { userPermission } from '../../../middleware/userPermission';
import multer from 'multer';
import path from 'path';
import config from '../../../config';

var attachmentDir = path.join(config.storage.folder, config.storage.course_logo);
var attachmentDirContent = path.join(config.storage.folder, config.storage.course_content);
var attachmentDirContentThumbnail = path.join(config.storage.folder, config.storage.course_content_thumbnail);

var storage = multer.diskStorage({
    destination: function (req, file, cb) {
        if (file.fieldname === "logo") cb(null, attachmentDir)
        if (file.fieldname === "filename") cb(null, attachmentDirContent)
        if (file.fieldname === "thumbnail") cb(null, attachmentDirContentThumbnail)
    },
    filename: function (req, file, cb) {
        var originalname = file.originalname;
        if (file.mimetype.includes('image')) originalname = file.originalname + '.png';
        cb(null, Date.now() + path.extname(originalname))
    }
})
var uploadAttachment = multer({ storage: storage, limits: { fileSize: 1024 * 1024 * 1024 },

});



export const courseRouter = express.Router();
const rateLimit = require("express-rate-limit");
const apiLimiter = rateLimit({
  windowMs: 1 * 60 * 1000, // 15 minutes
  max: 150, 
  message: "Too many accounts created from this IP, please try again after an hour"
});
courseRouter.route('/').get(sanitize(), jwtStrategy, userPermission('course-list'), courseController.fetch);
courseRouter.route('/member-course').get(sanitize(), jwtStrategy, userPermission('course'),courseController.fetchMemberCourse);// change router
courseRouter.route('/preview-course').get(sanitize(), jwtStrategy, userPermission('course-read'),courseController.previewCourse);
courseRouter.route('/').post(sanitize(),apiLimiter, jwtStrategy, userPermission('course-write'),uploadAttachment.single('logo'), courseController.store);
courseRouter.route('/list').get(sanitize(), jwtStrategy, userPermission('course-list'), courseController.list);
courseRouter.route('/settings').get(sanitize(), jwtStrategy, userPermission('course-read'), courseController.settings);
courseRouter.route('/course-status').get(sanitize(), jwtStrategy, userPermission('course-read'), courseController.courseStatus);
courseRouter.route('/delete-section').delete(sanitize(),apiLimiter, jwtStrategy, courseController.deleteSection);
courseRouter.route('/delete-lecture').delete(sanitize(),apiLimiter, jwtStrategy, courseController.deleteLecture);
courseRouter.route('/language').get(sanitize(), jwtStrategy, userPermission('course-read'),courseController.fetchLanguages);
courseRouter.route('/check-curriculum').get(sanitize(), jwtStrategy, userPermission('course-read'),courseController.checkCurriculum);
courseRouter.route('/section').patch(sanitize(),apiLimiter, jwtStrategy, userPermission('course-write'), courseController.updateSection);
courseRouter.route('/:id').patch(sanitize(),apiLimiter, jwtStrategy, userPermission('course-write'), uploadAttachment.single('logo'), courseController.update);
courseRouter.route('/section').post(sanitize(),apiLimiter, jwtStrategy, userPermission('course-write'), courseController.storeSection);
courseRouter.route('/section').get(sanitize(),apiLimiter, jwtStrategy, userPermission('course-read'), courseController.fetchSection);
courseRouter.route('/section/lecture').post(sanitize(['description']),apiLimiter, jwtStrategy, userPermission('course-write'),courseController.storeSectionLecture);
courseRouter.route('/section/updatelecture').patch(sanitize(['description']),apiLimiter,jwtStrategy, userPermission('course-write'), courseController.updateSectionLecture);
courseRouter.route('/upload-lecture-file').post(sanitize(),apiLimiter, jwtStrategy, userPermission('course-write'), uploadAttachment.fields([{ name: 'filename', maxCount: 1 }, { name: 'thumbnail', maxCount: 1 }]), courseController.uploadLectureFile);
courseRouter.route('/tracker').post(sanitize(), jwtStrategy,apiLimiter,courseController.tracker); // change router
courseRouter.route('/create-meeting').post(sanitize(),apiLimiter, jwtStrategy, userPermission('course-write'),courseController.createMeeting); // change router
// course within quiz
courseRouter.route('/lecture-questions').get(sanitize(),  jwtStrategy, userPermission('course-read'), courseController.lectureQuestions);
courseRouter.route('/create-lecture-question').post(sanitize(),  jwtStrategy, userPermission('course-write'), uploadAttachment.single('thumbnail'),courseController.storeQuestion);
courseRouter.route('/update/lecture/question').patch(sanitize(),  jwtStrategy, userPermission('course-write'), uploadAttachment.single('thumbnail'),courseController.updateQuestion);
courseRouter.route('/lecture-questions/:id/:lId').delete(sanitize(),  jwtStrategy, userPermission('course-delete'), courseController.deleteLectureQuestions);
courseRouter.route('/lecture-questions/:id').delete(sanitize(),  jwtStrategy, userPermission('course-delete'), courseController.deleteQuizQuestionOptions);